@@ -5,7 +5,7 @@ require "skkserv/skkdic.rb"
 require "test/unit/testcase"
 
 $jisyo = "/usr/share/skk/SKK-JISYO.L"
-$cachedir = "/var/lib/rskkserv"
+$cachedir = "./test/var"
 $nocache = nil
 
 $stdout.sync = true
